@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: LangUtil.pm,v 1.8 2010-11-25 02:33:05 dpchrist Exp $
+# $Id: LangUtil.pm,v 1.10 2010-11-25 19:33:31 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -14,12 +14,13 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw(
     arrayref_cmp
     defined_or
+    echo_system
     hashref_keys
 ) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.8 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.10 $ =~ /(\d+)/g);
 
 #######################################################################
 # uses:
@@ -37,6 +38,14 @@ Dpchrist::LangUtil - Perl language utilities
 
 =head1 DESCRIPTION
 
+This documentation describes module revision $Revision: 1.10 $.
+
+
+This is alpha test level software
+and may change or disappear at any time.
+
+
+
 =cut
 
 #######################################################################
@@ -103,6 +112,31 @@ sub defined_or
 
 #----------------------------------------------------------------------
 
+=head3 echo_system
+
+    echo_system LIST
+
+Prints newline,
+dollar sign,
+space,
+LIST items seperated by spaces,
+and newline to STDOUT,
+and then passes through call to system().
+
+=cut
+
+sub echo_system
+{
+    print
+	"\n\$ ",
+      	join(' ', @_),
+	"\n";
+    
+    return system @_;
+}
+
+#----------------------------------------------------------------------
+
 =head3 hashref_keys
 
     hashref_keys HASHREF
